;; Copyright (C) 2018  David Arroyo Menéndez

;; Author: David Arroyo Menéndez <davidam@gnu.org>
;; Maintainer: David Arroyo Menéndez <davidam@gnu.org>

;; This file is free software; you can redistribute it and/or modify
;; it under the terms of the GNU General Public License as published by
;; the Free Software Foundation; either version 3, or (at your option)
;; any later version.

;; This file is distributed in the hope that it will be useful,
;; but WITHOUT ANY WARRANTY; without even the implied warranty of
;; MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;; GNU General Public License for more details.

;; You should have received a copy of the GNU General Public License
;; along with GNU Emacs; see the file COPYING.  If not, write to
;; the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
;; Boston, MA 02110-1301 USA,

;;; Commentary:

;; This file implements functions to help to format in org-mode from
;; ASCII.
;; Org-mode doesn't load this module by default - if this is not what
;; you want, configure the variable `org-modules'.

;;; Code:

(require 'org)

(defun org-envolve-numbered-list()
  "Itemize some lines as a numbered list"
  (interactive)
  (setq num 1)
  (setq max (+ 1 (count-lines (point) (mark))))
  (if (> (point) (mark))
      (goto-line (+ 1 (count-lines 1 (mark))))
    (goto-line (+ 1 (count-lines 1 (point)))))
  (while (< num max)
    (move-beginning-of-line nil)
    (insert (concat (number-to-string num) ". "))
    (setq num (+ 1 num))
    (forward-line)))

(defun org-envolve-check-list()
  "Itemize some lines as a checked list"
  (interactive)
  (setq num 1)
  (setq max (+ 1 (count-lines (point) (mark))))
  (if (> (point) (mark))
      (goto-line (+ 1 (count-lines 1 (mark))))
    (goto-line (+ 1 (count-lines 1 (point)))))
  (while (< num max)
    (move-beginning-of-line nil)
    (insert (concat "+ [ ] "))
    (setq num (+ 1 num))
    (forward-line)))

(defun org-envolve-tags(msg)
  "Envolve source between org tags"
  (interactive "sChoose your programming language: " msg)
  (if (string= "" msg)
      (setq msg "lisp"))
  (if (> (point) (mark))
      (progn
	(goto-char (point))
	(insert "#+END_SRC")
	(goto-char (mark))
	(insert "#+BEGIN_SRC " msg "\n"))
    (progn
      (goto-char (point))
      (insert "#+BEGIN_SRC " msg "\n")
      (goto-char (mark))
      (insert "#+END_SRC"))))

(defun org-envolve-add-tags(msg)
  "Insert org source tags"
  (interactive "sChoose your programming language: " msg)
;; TODO: Meter name en interactive. Ej: #+name: myconcat
  (if (equal nil msg)
      (setq msg "lisp"))
  (insert "#+BEGIN_SRC " msg)
  (insert "\n#+END_SRC\n"))

(provide 'org-envolve)
